@@ -259,7 +259,7 @@ int imap_handle_untagged (IMAP_DATA *idata, char *s)
       mx_fastclose_mailbox (idata->selected_ctx);
     return (-1);
   }
-  else if (mutt_strncasecmp ("NO", s, 2) == 0)
+  else if (option (OPTIMAPSERVERNOISE) && (mutt_strncasecmp ("NO", s, 2) == 0))
   {
     /* Display the warning message from the server */
     mutt_error (s+3);
