@@ -789,23 +789,56 @@ generate_body (FILE *tempfp,	/* stream for outgoing message */
 void mutt_set_followup_to (ENVELOPE *e)
 {
   ADDRESS *t = NULL;
+  ADDRESS *from;
 
-  /* only generate the Mail-Followup-To if the user has requested it, and
+  /* 
+   * Only generate the Mail-Followup-To if the user has requested it, and
    * it hasn't already been set
    */
+
   if (option (OPTFOLLOWUPTO) && !e->mail_followup_to)
   {
-    if (mutt_is_list_recipient (0, e->to, e->cc))
+    if (mutt_is_list_cc (0, e->to, e->cc))
     {
-      /* i am a list recipient, so set the Mail-Followup-To: field so that
-       * i don't end up getting multiple copies of responses to my mail
+      /* 
+       * this message goes to known mailing lists, so create a proper
+       * mail-followup-to header
        */
+
       t = rfc822_append (&e->mail_followup_to, e->to);
       rfc822_append (&t, e->cc);
-      /* the following is needed if $metoo is set, because the ->to and ->cc
-	 may contain the user's private address(es) */
-      e->mail_followup_to = remove_user (e->mail_followup_to, 0);
     }
+
+    /* remove ourselves from the mail-followup-to header */
+    e->mail_followup_to = remove_user (e->mail_followup_to, 0);
+
+    /*
+     * If we are not subscribed to any of the lists in question,
+     * re-add ourselves to the mail-followup-to header.  The 
+     * mail-followup-to header generated is a no-op with group-reply,
+     * but makes sure list-reply has the desired effect.
+     */
+
+    if (e->mail_followup_to && !mutt_is_list_recipient (0, e->to, e->cc))
+    {
+      if (e->from)
+	from = rfc822_cpy_adr (e->from);
+      else
+	from = mutt_default_from ();
+      
+      if (from)
+      {
+	/* Normally, this loop will not even be entered. */
+	for (t = from; t && t->next; t = t->next)
+	  ;
+	
+	t->next = e->mail_followup_to; 	/* t cannot be NULL at this point. */
+	e->mail_followup_to = from;
+      }
+    }
+    
+    e->mail_followup_to = mutt_remove_duplicates (e->mail_followup_to);
+    
   }
 }
 
@@ -913,7 +946,7 @@ static int send_message (HEADER *msg)
 }
 
 /* rfc2047 encode the content-descriptions */
-static void encode_descriptions (BODY *b)
+static void encode_descriptions (BODY *b, short recurse)
 {
   BODY *t;
   char tmp[LONG_STRING];
@@ -925,8 +958,27 @@ static void encode_descriptions (BODY *b)
       rfc2047_encode_string (tmp, sizeof (tmp), (unsigned char *) t->description);
       mutt_str_replace (&t->description, tmp);
     }
+    if (recurse && t->parts)
+      encode_descriptions (t->parts, recurse);
+  }
+}
+
+/* rfc2047 decode them in case of an error */
+static void decode_descriptions (BODY *b)
+{
+  BODY *t;
+  char tmp[LONG_STRING];
+  
+  for (t = b; t; t = t->next)
+  {
+    if (t->description)
+    {
+      /* this should really have the same interface as rfc2047_encode_string. */
+      rfc2047_decode (tmp, t->description, sizeof (tmp));
+      mutt_str_replace (&t->description, tmp);
+    }
     if (t->parts)
-      encode_descriptions (t->parts);
+      decode_descriptions (t->parts);
   }
 }
 
@@ -1309,11 +1361,14 @@ main_loop:
   if (msg->content->next)
     msg->content = mutt_make_multipart (msg->content);
 
-  /* Ok, we need to do it this way instead of handling all fcc stuff in
+  /* 
+   * Ok, we need to do it this way instead of handling all fcc stuff in
    * one place in order to avoid going to main_loop with encoded "env"
    * in case of error.  Ugh.
    */
 
+  encode_descriptions (msg->content, 1);
+  
 #ifdef HAVE_PGP
   if (msg->pgp)
   {
@@ -1327,9 +1382,11 @@ main_loop:
       
       if (pgpkeylist)
 	FREE (&pgpkeylist);
-
+      
+      decode_descriptions (msg->content);
       goto main_loop;
     }
+    encode_descriptions (msg->content, 0);
   }
 
   /* 
@@ -1347,7 +1404,6 @@ main_loop:
     mutt_message _("Sending message...");
 
   mutt_prepare_envelope (msg->env);
-  encode_descriptions (msg->content);
 
   /* save a copy of the message, if necessary. */
 
